==> chromium-browser-24.0.1312.52.tar.xz: chromium-browser-24.0.1312.52/src/chrome/browser/chromeos/input_method/browser_state_monitor.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_INPUT_METHOD_BROWSER_STATE_MONITOR_H_
#define CHROME_BROWSER_CHROMEOS_INPUT_METHOD_BROWSER_STATE_MONITOR_H_

#include <string>

#include "chrome/browser/api/prefs/pref_member.h"
#include "chrome/browser/chromeos/input_method/input_method_manager.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
#include "content/public/browser/notification_types.h"

class PrefService;

namespace chromeos {
namespace input_method {

// A class which monitors a notification from the browser to keep track of the
// browser state (not logged in, logged in, etc.) and notify the current state
// to the input method manager. The class also updates the appropriate Chrome
// prefs (~/Local\ State or ~/Preferences) depending on the current browser
// state.
class BrowserStateMonitor : public content::NotificationObserver,
                            public InputMethodManager::Observer {
 public:
  explicit BrowserStateMonitor(InputMethodManager* manager);
  virtual ~BrowserStateMonitor();

  InputMethodManager::State state() const { return state_; }

  void SetPrefServiceForTesting(PrefService* pref_service);

 protected:
  // Updates ~/Local\ State file. protected: for testing.
  virtual void UpdateLocalState(const std::string& current_input_method);
  // Updates ~/Preferences file. protected: for testing.
  virtual void UpdateUserPreferences(const std::string& current_input_method);

  // InputMethodManager::Observer overrides:
  virtual void InputMethodChanged(InputMethodManager* manager,
                                  bool show_message) OVERRIDE;
  virtual void InputMethodPropertyChanged(InputMethodManager* manager) OVERRIDE;

  // content::NotificationObserver overrides:
  virtual void Observe(int type,
                       const content::NotificationSource& source,
                       const content::NotificationDetails& details) OVERRIDE;

 private:
  void SetState(InputMethodManager::State new_state);
  void InitializePrefMembers();

  InputMethodManager* manager_;
  InputMethodManager::State state_;

  // This is used to register this object to some browser notifications.
  content::NotificationRegistrar notification_registrar_;

  // For testing.
  PrefService* pref_service_;

  DISALLOW_COPY_AND_ASSIGN(BrowserStateMonitor);
};

}  // namespace input_method
}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_INPUT_METHOD_BROWSER_STATE_MONITOR_H_

==> chromium-browser-25.0.1364.97.tar.xz: chromium-browser-25.0.1364.97/src/chrome/browser/chromeos/input_method/browser_state_monitor.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_INPUT_METHOD_BROWSER_STATE_MONITOR_H_
#define CHROME_BROWSER_CHROMEOS_INPUT_METHOD_BROWSER_STATE_MONITOR_H_

#include <string>

#include "base/basictypes.h"
#include "base/callback.h"
#include "base/compiler_specific.h"
#include "chrome/browser/chromeos/input_method/input_method_manager.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"

namespace chromeos {
namespace input_method {

// Translates notifications from the browser (not logged in, logged in, etc.),
// into InputMethodManager::State transitions.
class BrowserStateMonitor : public content::NotificationObserver {
 public:
  // Constructs a monitor that will invoke the given observer callback whenever
  // the InputMethodManager::State changes. Assumes that the current state is
  // STATE_LOGIN_SCREEN. |observer| may be null.
  explicit BrowserStateMonitor(
      const base::Callback<void(InputMethodManager::State)>& observer);
  virtual ~BrowserStateMonitor();

  InputMethodManager::State state() const { return state_; }

  // content::NotificationObserver overrides:
  virtual void Observe(int type,
                       const content::NotificationSource& source,
                       const content::NotificationDetails& details) OVERRIDE;

 private:
  base::Callback<void(InputMethodManager::State)> observer_;
  InputMethodManager::State state_;
  content::NotificationRegistrar notification_registrar_;

  DISALLOW_COPY_AND_ASSIGN(BrowserStateMonitor);
};

}  // namespace input_method
}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_INPUT_METHOD_BROWSER_STATE_MONITOR_H_
